4.3. oncilla.defaultSanitizer — Oncilla 0.1.0 documentation

# 4.3. oncilla.defaultSanitizer

defaultSanitizer.py

Platform:
  Windows, Linux, Mac Os X.
Description:
  Sanitizes python module file. `bleach()` definition is called by Oncilla package.

Others:

## 4.3.1. Module Attributes

`oncilla.defaultSanitizer.` `LOGGER`

`oncilla.defaultSanitizer.` `STATEMENT_UPDATE_MESSAGE`

`oncilla.defaultSanitizer.` `STATEMENT_SUBSTITUTE`

## 4.3.2. Functions

`oncilla.defaultSanitizer.` `bleach`(file)

  Sanitizes given python module.

  Parameters: | file (unicode) – Python module file.
  Returns: | Definition success.
  Return type: | bool